@@ -32,13 +32,13 @@ def validate_create_report_attributes(enable_patterns_report: bool,
         raise TypeError('''provided patterns_report_group_by_numerical_features is not valid.
         patterns_report_group_by_numerical_features has to be a str == "all" or a list of numerical features''')
 
-    if type(
-            patterns_report_group_by_categorical_features) is str and patterns_report_group_by_categorical_features != 'all':
+    if type(patterns_report_group_by_categorical_features) is str \
+            and patterns_report_group_by_categorical_features != 'all':
         raise AttributeError('''provided patterns_report_group_by_categorical_features is not valid.
             patterns_report_group_by_categorical_features has to be "all" if the provided value is a string''')
 
-    if type(
-            patterns_report_group_by_numerical_features) is str and patterns_report_group_by_numerical_features != 'all':
+    if type(patterns_report_group_by_numerical_features) is str \
+            and patterns_report_group_by_numerical_features != 'all':
         raise AttributeError('''provided patterns_report_group_by_numerical_features is not valid.
             patterns_report_group_by_numerical_features has to be "all" if the provided value is a string''')
 
@@ -60,13 +60,13 @@ def validate_create_report_attributes(enable_patterns_report: bool,
         raise TypeError('''provided patterns_report_number_of_bins is not valid.
         patterns_report_number_of_bins has to be an int or a list of ints (one for each numerical feature provided in patterns_report_group_by_numerical_features)''')
 
-    if is_instance(patterns_report_number_of_bins, List[int]) and type(
-            patterns_report_group_by_numerical_features) is str:
+    if is_instance(patterns_report_number_of_bins, List[int]) \
+            and type(patterns_report_group_by_numerical_features) is str:
         raise AttributeError('''provided patterns_report_number_of_bins is not valid.
         patterns_report_number_of_bins can be a list of ints if a list of numerical features were provided in patterns_report_group_by_numerical_features''')
 
-    if is_instance(patterns_report_number_of_bins, List[int]) and is_instance(
-            patterns_report_group_by_numerical_features, List[str]):
+    if is_instance(patterns_report_number_of_bins, List[int]) \
+            and is_instance(patterns_report_group_by_numerical_features, List[str]):
         if len(patterns_report_number_of_bins) != len(patterns_report_group_by_numerical_features):
             raise AttributeError('''provided patterns_report_number_of_bins is not valid.
             patterns_report_number_of_bins list length has to be equal to the number of features provided in patterns_report_group_by_numerical_features''')
@@ -138,20 +138,20 @@ def validate_attributes(train_df, test_df, target_feature_name, error_column_nam
                             \ntarget_feature_name ({target_feature_name}) has to be a str''')
 
     if target_feature_name not in train_columns:
-        raise TypeError(f'provided target_feature_name ({target_feature_name}) is not train_df')
+        raise AttributeError(f'provided target_feature_name ({target_feature_name}) is not train_df')
 
     if target_feature_name not in test_columns:
-        raise TypeError(f'provided target_feature_name ({target_feature_name}) is not test_df')
+        raise AttributeError(f'provided target_feature_name ({target_feature_name}) is not test_df')
 
     if type(error_column_name) is not str:
         raise TypeError(f'''provided error_column_name is not valid.
                             \ntest_error_column_name ({error_column_name}) has to be a str''')
 
     if error_column_name not in train_columns:
-        raise TypeError(f'provided error_column_name ({error_column_name}) is not train_df')
+        raise AttributeError(f'provided error_column_name ({error_column_name}) is not train_df')
 
     if error_column_name not in test_columns:
-        raise TypeError(f'provided error_column_name ({error_column_name}) is not test_df')
+        raise AttributeError(f'provided error_column_name ({error_column_name}) is not test_df')
 
     if not is_instance(error_classes, Dict[str, Tuple[float, float]]):
         raise TypeError('provided error_classes is not valid. error_classes has to be a Dict[str, Tuple[float, float]]')
@@ -161,7 +161,7 @@ def validate_attributes(train_df, test_df, target_feature_name, error_column_nam
                             \nacceptable_error_class ({acceptable_error_class}) has to be a str or None''')
 
     if acceptable_error_class is not None and acceptable_error_class not in error_classes:
-        raise TypeError(f'''provided acceptable_error_class is not valid.
+        raise AttributeError(f'''provided acceptable_error_class is not valid.
                             \n{acceptable_error_class} has to be defined in error_classes''')
 
     if numerical_features is None and categorical_features is None:
@@ -321,6 +321,7 @@ class RegressionErrorAnalysisReport(Report):
         :return: None
         """
 
+        self.report_data['report'] = {}
         validate_create_report_attributes(enable_patterns_report,
                                           patterns_report_group_by_categorical_features,
                                           patterns_report_group_by_numerical_features,
