@@ -21,7 +21,7 @@ def validate_attributes(title, output_directory, subtitle, report_folder_name, e
     if encryption_secret is not None and type(encryption_secret) is not str:
         raise TypeError(f'provided encryption_secret is not valid. encryption_secret has to be a str')
     if encryption_secret is not None and len(encryption_secret) != 16:
-        raise TypeError(f'provided encryption_secret is not valid. encryption_secret has to be 16 characters')
+        raise AttributeError(f'provided encryption_secret is not valid. encryption_secret has to be 16 characters')
     if type(generate_encryption_secret) is not bool:
         raise TypeError(f'provided generate_encryption_secret is not valid. encryption_secret has to be a bool')
 
@@ -42,12 +42,6 @@ def _copy_application_template(template_name: str, destination_path: str) -> Non
     copy_tree(source_path, destination_path)
 
 
-def _zip_directory(path: str, zip_handler):
-    for root, dirs, files in os.walk(path):
-        for file in files:
-            zip_handler.write(os.path.join(root, file))
-
-
 def _start_server_and_view_report(report_directory: str, mode: str, port: int) -> None:
     """
     Serve the report to the user using a web server.
@@ -60,9 +54,6 @@ def _start_server_and_view_report(report_directory: str, mode: str, port: int) -
     :param port: the server port. default: random between (1024-49151)
     :return: None
     """
-    print('''\n\n ### \nServing the report this way, might not work on all machines.
-Try different server mode ('server', 'js' or 'jupyter') or save and download the report and open index.html \n###\n\n''')
-    print('Clear your browser\'s cache if your report was not updated\n\n')
     import multiprocessing as mp
     import time
     import importlib.util
@@ -162,7 +153,7 @@ class Report:
         """
         self.report_data['report'].update(data)
 
-    def _serve_report_using_flask(self, template_name: str, mode: str, port: int) -> None:
+    def _serve_report_using_flask(self, template_name: str, mode: str, port: int, load_existing_data: bool = False) -> None:
         """
         Creates the report directory, copies the web application based on the template name,
         saves the report data and starts the flask server.
@@ -170,11 +161,13 @@ class Report:
         :param template_name: the name of the report's template
         :param mode: the server mode
         :param port: the server port
+        :param load_existing_data: load existing json data
         :return: None
         """
         report_directory = self._create_report_directory()
         _copy_application_template(template_name, report_directory)
-        self._save_report_data(report_directory)
+        if not load_existing_data:
+            self._save_report_data(report_directory)
         _start_server_and_view_report(report_directory, mode, port)
 
     def _save_the_report(self, template_name: str, zip_report: bool) -> None:
